@@ -1,23 +1,26 @@
 import sys
 import os
 import argparse
+from pkg_resources import get_distribution
 
 from impactlib.refresh import refresh
 from impactlib.search import search
 from impactlib.install import install
-from impactlib.config import ENVVAR
+from impactlib.config import ENVVAR, get_config_file, get, get_indices
+
 
 parser = argparse.ArgumentParser(prog='impact')
 subparsers = parser.add_subparsers(help='command help')
 
 def call_info(args):
-    from impactlib.config import get_config_file, get, get_indices
+    print("impact version: %s" % get_distribution("impact").version )
     print("Configuration file: "+get_config_file())
     print("  indices="+str(get_indices()))
     for key in ["token", "username", "password", "source_list"]:
         val = get("Impact", key)
         if val:
-            print("  %s=%s" % (key, get("Impact",key)))
+            print("  %s=%s" % (key, get("Impact", key)))
+    print("Current working dir(default target): %s" % os.getcwd())
 
 def call_refresh(args):
     if args.source_list==[] or args.source_list==None:
@@ -78,7 +81,7 @@ def main(args=None):
     parser_install.add_argument("-d", "--dry_run", action="store_true",
                                 help="Suppress installation", required=False)
     parser_install.add_argument("-t", "--target", default=".",
-                                help="Target installation directory", required=False)
+                                help="Target installation directory (default: current dir)", required=False)
     parser_install.set_defaults(func=call_install)
 
     parser_info = subparsers.add_parser("info", help="Show config settings")
